add_block_to_dynamic_tables

Function add_block_to_dynamic_tables 

pub fn add_block_to_dynamic_tables<'a, I: Iterator<Item = Cow<'a, Transaction<Pruned>>>>(
    db: &BlockchainDatabase,
    block: &Block,
    block_hash: &BlockHash,
    txs: I,
    numb_transactions: &mut u64,
    w: &mut OwnedWriteBatch,
    pre_rct_numb_outputs_cache: &mut HashMap<Amount, u64>,
) -> DbResult<()>
Add a [VerifiedBlockInformation] to the dynamic database (fjall).

This extracts all the data from the input block and maps/adds them to the appropriate database tables.

Panics

This function will panic if the block is invalid.