pub fn add_blocks_to_tapes(
blocks: &[VerifiedBlockInformation],
db: &BlockchainDatabase,
append_tx: &mut TapesAppendTransaction<'_>,
) -> DbResult<()>Expand description
Write a slice of contiguous blocks to the tapes database.
The blocks must follow directly from the top of the chain.
Panic
This will panic if the given blocks cross 3 pruning stripes.