pub fn get_block(
block_height: &BlockHeight,
blocks_info: Option<&BlockInfo>,
tapes: &impl TapesRead,
db: &BlockchainDatabase,
) -> DbResult<Block>Expand description
Retrieve a [Block] via its BlockHeight.
If the block info is given, it will not be looked up, which can be useful when the info is popped.